"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ModalBackdrop = exports.Modal = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _noScroll = _interopRequireDefault(require("no-scroll"));

var _focusTrapReact = _interopRequireDefault(require("focus-trap-react"));

var _reactHooksShareable = require("react-hooks-shareable");

var _Practical = require("../Practical");

var _useEscapeListenerStack = require("./hooks/useEscapeListenerStack");

var _designparams = require("../designparams");

var _jsxRuntime = require("react/jsx-runtime");

var _excluded = ["children"],
    _excluded2 = ["open", "onClose", "focusDialog", "children"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * CloseOnEscape sets up and tears down the "close on escape" logic
 */
var CloseOnEscape = _ref => {
  var {
    onClose
  } = _ref;
  var [escPressed, setEscPressed] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    if (escPressed) {
      onClose();
    }
  }, [escPressed, onClose]); // escape handler must be constant

  var escapeHandler = (0, _react.useCallback)(evt => {
    evt.preventDefault();
    setEscPressed(true);
  }, [setEscPressed]);
  (0, _useEscapeListenerStack.useEscapeListenerStack)(escapeHandler);
  return null;
};

var ModalContainer = _styledComponents.default.div.withConfig({
  displayName: "Modal__ModalContainer",
  componentId: "sc-r9x817-0"
})(["background-color:", ";position:fixed;top:0;left:0;bottom:0;right:0;display:flex;align-items:center;justify-content:center;height:100%;width:100%;"], _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.color.text01(_designparams.opacity[48]);
});

var FocusWrapper = _styledComponents.default.div.withConfig({
  displayName: "Modal__FocusWrapper",
  componentId: "sc-r9x817-1"
})(["outline:0px;"]);

var ModalBackdrop = _ref3 => {
  var {
    children
  } = _ref3,
      props = _objectWithoutProperties(_ref3, _excluded);

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Practical.Layer, {
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(ModalContainer, _objectSpread(_objectSpread({}, props), {}, {
      children: children
    }))
  });
};

exports.ModalBackdrop = ModalBackdrop;

var Modal = _ref4 => {
  var {
    open,
    onClose,
    focusDialog = true,
    children
  } = _ref4,
      props = _objectWithoutProperties(_ref4, _excluded2);

  (0, _react.useEffect)(() => {
    if (open) {
      _noScroll.default.on();

      return () => _noScroll.default.off();
    }
  }, [open]);
  var id = (0, _reactHooksShareable.useId)('practical-modal');
  /**
   * Render
   */

  if (!open) {
    return null;
  }

  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(ModalBackdrop, _objectSpread(_objectSpread({}, props), {}, {
    children: [onClose !== undefined ? /*#__PURE__*/(0, _jsxRuntime.jsx)(CloseOnEscape, {
      onClose: onClose
    }) : null, /*#__PURE__*/(0, _jsxRuntime.jsx)(_focusTrapReact.default, {
      focusTrapOptions: {
        initialFocus: focusDialog ? "#".concat(id) : undefined,
        escapeDeactivates: false,
        // We use our own stack
        clickOutsideDeactivates: true // 😱😱😱 We need this to prevent click capturing

      },
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(FocusWrapper, {
        tabIndex: -1,
        id: id,
        children: children
      })
    })]
  }));
};

exports.Modal = Modal;