"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PopOver = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _Practical = require("../Practical");

var _utils = require("./utils");

var _jsxRuntime = require("react/jsx-runtime");

var _excluded = ["anchorEl", "horizontalPosition", "verticalPosition", "horizontalAlignment", "verticalAlignment", "onPosition", "onScroll", "children"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var PopOverContainer = _styledComponents.default.div.withConfig({
  displayName: "PopOver__PopOverContainer",
  componentId: "sc-1gkk5kl-0"
})(["position:fixed;"]);
/**
 * Pop-over component
 *
 * Used to render some content positioned relative to an anchor, but as a child
 * of the document. By default the PopOver content is positioned below the
 * anchor aligned to the left. When the content would overflow the document, it's
 * repositioned stay within the document boundaries.
 */


var PopOver = _ref => {
  var {
    anchorEl,
    horizontalPosition = 'left',
    verticalPosition = 'bottom',
    horizontalAlignment = 'left',
    verticalAlignment = 'top',
    onPosition,
    onScroll,
    children
  } = _ref,
      props = _objectWithoutProperties(_ref, _excluded);

  var [popOverContainer, setPopOverContainer] = (0, _react.useState)(null);
  var {
    el: layerRoot
  } = (0, _react.useContext)(_Practical.LayerContext);
  var position = (0, _react.useCallback)(() => {
    // Position the pop-over element synchronously
    if (anchorEl !== null && popOverContainer !== null) {
      if (onPosition === undefined) {
        (0, _utils.anchorPosition)(anchorEl, popOverContainer, {
          horizontalPosition,
          verticalPosition,
          horizontalAlignment,
          verticalAlignment
        });
        return;
      }

      onPosition(anchorEl, popOverContainer);
    }
  }, [horizontalPosition, verticalPosition, horizontalAlignment, verticalAlignment, anchorEl, onPosition, popOverContainer]);
  (0, _utils.useOnScrollEffect)(anchorEl, onScroll !== undefined ? onScroll : () => {
    /** */
  }); // Used when resizing the parent anchorEl

  (0, _utils.useOnResizeParentEffect)(anchorEl, position);
  (0, _utils.useOnResizeEffect)(popOverContainer, position); // Reposition on initialize

  (0, _react.useLayoutEffect)(() => {
    position();
  }, [position, popOverContainer]); // When the layer element is not available, there is no layer yet.

  if (layerRoot === null) {
    return null;
  }

  return /*#__PURE__*/_reactDom.default.createPortal( /*#__PURE__*/(0, _jsxRuntime.jsx)(PopOverContainer, _objectSpread(_objectSpread({
    ref: setPopOverContainer
  }, props), {}, {
    children: children
  })), layerRoot);
};

exports.PopOver = PopOver;