"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PracticalProvider = exports.LayerContext = exports.Layer = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _resizeObserver = require("@juggle/resize-observer");

var _reactHooksShareable = require("react-hooks-shareable");

var _theme = require("./theme");

var _ToastsProvider = require("./Toast/ToastsProvider");

var _jsxRuntime = require("react/jsx-runtime");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var PracticalRoot = _styledComponents.default.div.withConfig({
  displayName: "Practical__PracticalRoot",
  componentId: "sc-1lggjit-0"
})(["color:", ";"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.text01();
});

var PracticalContext = /*#__PURE__*/(0, _react.createContext)({
  rootEl: undefined
});
var DEFAULT_TOASTS_OPTIONS = {
  placement: {
    justify: 'right',
    top: '0'
  },
  alwaysOnTop: true,
  defaultDurations: {
    success: 4000
  }
};

var PracticalProvider = _ref2 => {
  var {
    theme = _theme.defaultTheme,
    toastsOptions,
    children
  } = _ref2;
  var [rootEl, rootRef] = (0, _react.useState)(null);

  var mergedOptions = _objectSpread(_objectSpread({}, DEFAULT_TOASTS_OPTIONS), toastsOptions);

  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_styledComponents.ThemeProvider, {
    theme: theme,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(PracticalContext.Provider, {
      value: {
        rootEl
      },
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_ToastsProvider.ToastsProvider, _objectSpread(_objectSpread({}, mergedOptions.defaultDurations), {}, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(PracticalRoot, {
          id: "practical-root",
          ref: rootRef,
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(Layer, {
            children: children
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(Layer, {
            zIndex: mergedOptions.alwaysOnTop ? 1 : 0,
            children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_ToastsProvider.ToastsAnchor, {
              placement: mergedOptions.placement
            })
          })]
        })
      }))
    })
  });
};
/**
 * Layer
 *
 * A layer creates a new div element that is rendered
 * a sibling to the previous layer and a child of the
 * practical root.
 *
 * Other components can access the layer element and id
 * through the LayerContext.
 *
 * Layers cannot be clicked on, but all children of it
 * can be clicked on. Wowy!
 */


exports.PracticalProvider = PracticalProvider;
var LAYER_ID_PREFIX = 'layer';

var LayerContainer = _styledComponents.default.div.withConfig({
  displayName: "Practical__LayerContainer",
  componentId: "sc-1lggjit-1"
})(["position:absolute;z-index:", ";"], _ref3 => {
  var {
    zIndex = 0
  } = _ref3;
  return zIndex;
});

var LayerContext = /*#__PURE__*/(0, _react.createContext)({
  el: typeof document !== 'undefined' ? document.body : null,
  id: LAYER_ID_PREFIX
});
exports.LayerContext = LayerContext;

var Layer = _ref4 => {
  var {
    children,
    zIndex
  } = _ref4;
  var {
    rootEl
  } = (0, _react.useContext)(PracticalContext);
  var [el, ref] = (0, _react.useState)(null);
  var id = (0, _reactHooksShareable.useId)(LAYER_ID_PREFIX);

  if (rootEl === undefined) {
    throw new Error('You need to wrap your application in a PracticalProvider component, otherwise layers do not work.');
  }

  if (rootEl === null) {
    return null;
  }

  return /*#__PURE__*/_reactDom.default.createPortal( /*#__PURE__*/(0, _jsxRuntime.jsx)(LayerContext.Provider, {
    value: {
      el,
      id
    },
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(LayerContainer, {
      id: id,
      ref: ref,
      zIndex: zIndex,
      children: children
    })
  }), rootEl);
}; // Add ResizeObserver polyfill from juggle if not available


exports.Layer = Layer;

if (typeof window !== 'undefined') {
  if (window.ResizeObserver === undefined) {
    /* eslint-disable-next-line @typescript-eslint/ban-ts-comment */
    // @ts-ignore
    window.ResizeObserver = _resizeObserver.ResizeObserver;
  }
}